cls

*==============================================================================
* Numeracy scores 
use "$clean_data/Math_PBA", clear


* Creating percentiles for each assessment
local xtiles=100

* Creating a temporary variable just for the sake of simplifying the loop below
	gen std_pba_math=total_score_irt
	gen std_in_person_math=in_person_score

*=== Classifying students based on their relative positions in the distribution	
foreach v in feb20 oct19 jul19 pba in_person{
egen ptile_`v'=xtile(std_`v'_math) if total_score_irt!=., by(grade_2020) nq(`xtiles')
}

* Dropping temporary variables 
drop std_pba_math std_in_person_math

*=== Creating gap variables
gen class_gap= ptile_feb20- ptile_oct19
gen pba_gap= ptile_feb20- ptile_pba
gen class_in_person_gap= ptile_feb20- ptile_in_person
gen pba_gap_in_person= ptile_in_person- ptile_pba

* Gap in gap variable:
gen gap_in_gap=pba_gap-class_gap
gen gap_in_gap_in_person=pba_gap-pba_gap_in_person
	
	
*=== I want to quantify the share of students misclassified 
forvalues v=0(1)`xtiles'{
	gen misclassified_class_`v'=(abs(ptile_feb20-ptile_oct19)>`v')
		sum  misclassified_class_`v'
	gen misclassified_pba_`v'=(abs(ptile_feb20-ptile_pba)>`v')
		sum  misclassified_pba_`v'
	gen misclassified_in_person_`v'=(abs(ptile_feb20-ptile_in_person)>`v')
		sum  misclassified_pba_`v'
} 
 
* For each baseline percentile, I want to calculate the baseline gap for each test 
foreach v in pba_gap class_gap class_in_person_gap pba_gap_in_person{
		bys ptile_feb20: egen mean_`v'	=mean(`v')
			label var mean_`v'   "Mean `v' by baseline percentile"
}
 
*=== Labeling variables 	
label var ptile_feb20   "Student's percentile on in-class Feb/20 assessment"
label var ptile_oct19   "Student's percentile on in-class Oct/19 assessment"
label var ptile_jul19   "Student's percentile on in-class Jul/19 assessment"
label var ptile_pba   "Student's percentile on PBA assessment"
label var class_gap "Gap between Feb/20 and Oct/19"
label var pba_gap "Gap between Feb/20 and PBA"
label var class_in_person_gap "Gap between Feb/20 and in-person recreation of PBA"
label var pba_gap_in_person "Gap between in-person recreation of PBA and PBA"
label var gap_in_gap   "Gap in gap of assessments (between Feb/20-PBA and Feb/20-Oct/19)"
label var gap_in_gap_in_person   "Gap in gap of assessments (between Feb/20-PBA and in-person recreation of PBA-PBA)"


forvalues i=0(1)`xtiles'{
label var misclassified_class_`i' "Student is misclassified based on a thrsehold of +/- `i' percentiles on in-class assessment from Oct/19"
label var misclassified_pba_`i' "Student is misclassified based on a thrsehold of +/- `i' percentiles on PBA"
label var misclassified_in_person_`i' "Student is misclassified based on a thrsehold of +/- `i' percentiles on in-person recreation of PBA"

}

use "$clean_data/Math_PBA_percentiles", clear


*==============================================================================
* Literacy scores 
use "$clean_data/Fluency_PBA", clear

* Creating percentiles for each assessment
local xtiles=100

* Creating a temporary variable just for the sake of simplifying the loop below
	gen std_pba_english=total_score_english_pba

*=== Classifying students based on their relative positions in the distribution	
foreach v in feb21 mar21 pba{
egen ptile_`v'=xtile(std_`v'_english) if total_score_english_pba!=., by(grade_2020) nq(`xtiles')
}

* Dropping temporary variables 
drop std_pba_english 

*=== Creating gap variables
gen class_gap= ptile_mar21- ptile_feb21
gen pba_gap= ptile_mar21- ptile_pba

* Gap in gap variable:
gen gap_in_gap=pba_gap-class_gap	
	
*=== I want to quantify the share of students misclassified 
forvalues v=0(1)`xtiles'{
	gen misclassified_class_`v'=(abs(ptile_mar21-ptile_feb21)>`v')
		sum  misclassified_class_`v'
	gen misclassified_pba_`v'=(abs(ptile_mar21-ptile_pba)>`v')
		sum  misclassified_pba_`v'
} 
 
* For each baseline percentile, I want to calculate the baseline gap for each test 
foreach v in pba_gap class_gap{
		bys ptile_mar21: egen mean_`v'	=mean(`v')
			label var mean_`v'   "Mean `v' by baseline percentile"
}
 
*=== Labeling variables 	
label var ptile_mar21   "Student's percentile on in-class Mar/21 assessment"
label var ptile_feb21   "Student's percentile on in-class Feb/21 assessment"
label var ptile_pba   "Student's percentile on PBA assessment"
label var class_gap "Gap between Mar/21 and Feb/21"
label var pba_gap "Gap between Mar/21 and PBA"
label var gap_in_gap   "Gap in gap of assessments (between Mar/21-PBA and Feb/21)"


forvalues i=0(1)`xtiles'{
label var misclassified_class_`i' "Student is misclassified based on a thrsehold of +/- `i' percentiles on in-class assessment from Oct/19"
label var misclassified_pba_`i' "Student is misclassified based on a thrsehold of +/- `i' percentiles on PBA"
}
use "$clean_data/English_PBA_percentiles", clear
