*=================================================
* Appendix Figure A.2: testing robustness of different misclassification curves by reported shocks
*=================================================

*-----------------------------------
* INCOME SHOCK
*-----------------------------------

use "$clean_pba_num_percentile", clear

*  Reshaping data so it is in the correct shape for plotting curves
forvalues i=0/1{
	preserve
	keep if par_q4_income_shock==`i'
	
foreach v in class pba in_person{
	forvalues i=0(1)100{
		sum  misclassified_`v'_`i'
			replace  misclassified_`v'_`i'=r(mean)
	} 	
}
	 
keep misclassified_class_* misclassified_pba_*  misclassified_in_person_*
duplicates drop

gen id=1

reshape long misclassified_pba_ misclassified_class_ misclassified_in_person_, i(id) j(threshold)  string
keep  threshold misclassified_class_ misclassified_pba_ misclassified_in_person_
	destring threshold, replace

* Labeling	
	label variable misclassified_pba_ "Share of students misclassified by PBA"
	label variable misclassified_class_ "Share of students misclassified by previous in-class assessment"
	label variable misclassified_in_person_ "Share of students misclassified by in-person recreation of PBA"
	

	
*=== Actually producting graph	
sort threshold	
	keep if threshold<51
line misclassified_pba_ misclassified_class_  threshold,  legend(order(1 "Share of students misclassified by phone-based assessment (PBA)" 2 "Share of students misclassified by previous in-class assessment") cols(1)) legend(size(small)) title("Numeracy: relative misclassification rate of students by different thresholds", size(medium)) xtitle("Misclassification threshold", size(medsmall)) ytitle("Share of students misclassified", size(medsmall)) lpattern (solid dash)

restore
}

					  

*-----------------------------------
* HOUSING SHOCK
*-----------------------------------
use "$clean_pba_num_percentile", clear

*  Reshaping data so it is in the correct shape for plotting curves
forvalues i=0/1{
	preserve
	keep if par_q4_moved_home==`i'
	
foreach v in class pba in_person{
	forvalues i=0(1)100{
		sum  misclassified_`v'_`i'
			replace  misclassified_`v'_`i'=r(mean)
	} 	
}
	 
keep misclassified_class_* misclassified_pba_*  misclassified_in_person_*
duplicates drop

gen id=1

reshape long misclassified_pba_ misclassified_class_ misclassified_in_person_, i(id) j(threshold)  string
keep  threshold misclassified_class_ misclassified_pba_ misclassified_in_person_
	destring threshold, replace

* Labeling	
	label variable misclassified_pba_ "Share of students misclassified by PBA"
	label variable misclassified_class_ "Share of students misclassified by previous in-class assessment"
	label variable misclassified_in_person_ "Share of students misclassified by in-person recreation of PBA"
	
	
*=== Actually producting graph	
sort threshold	
	keep if threshold<51
line misclassified_pba_ misclassified_class_  threshold,  legend(order(1 "Share of students misclassified by phone-based assessment (PBA)" 2 "Share of students misclassified by previous in-class assessment") cols(1)) legend(size(small)) title("Numeracy: relative misclassification rate of students by different thresholds", size(medium)) xtitle("Misclassification threshold", size(medsmall)) ytitle("Share of students misclassified", size(medsmall)) lpattern (solid dash)

restore
}

				   

*-----------------------------------
* HEALTH SHOCK
*-----------------------------------

use "$clean_pba_num_percentile", clear

*  Reshaping data so it is in the correct shape for plotting curves
forvalues i=0/1{
	preserve
	keep if par_q4_health_shock==`i'
	
foreach v in class pba in_person{
	forvalues i=0(1)100{
		sum  misclassified_`v'_`i'
			replace  misclassified_`v'_`i'=r(mean)
	} 	
}
	 
keep misclassified_class_* misclassified_pba_*  misclassified_in_person_*
duplicates drop

gen id=1

reshape long misclassified_pba_ misclassified_class_ misclassified_in_person_, i(id) j(threshold)  string
keep  threshold misclassified_class_ misclassified_pba_ misclassified_in_person_
	destring threshold, replace

* Labeling	
	label variable misclassified_pba_ "Share of students misclassified by PBA"
	label variable misclassified_class_ "Share of students misclassified by previous in-class assessment"
	label variable misclassified_in_person_ "Share of students misclassified by in-person recreation of PBA"
	

	
*=== Actually producting graph	
sort threshold	
	keep if threshold<51
line misclassified_pba_ misclassified_class_  threshold,  legend(order(1 "Share of students misclassified by phone-based assessment (PBA)" 2 "Share of students misclassified by previous in-class assessment") cols(1)) legend(size(small)) title("Numeracy: relative misclassification rate of students by different thresholds", size(medium)) xtitle("Misclassification threshold", size(medsmall)) ytitle("Share of students misclassified", size(medsmall)) lpattern (solid dash)

restore
}

					

*-----------------------------------
* ANY SHOCK
*-----------------------------------
use "$clean_pba_num_percentile", clear
replace par_q4_no_shock=(par_q4_no_shock-1)*(-1) // just changing this so it's in the "positive" (i.e., yes=experienced any shock)

*  Reshaping data so it is in the correct shape for plotting curves
forvalues i=0/1{
	preserve
	keep if par_q4_no_shock==1
	
foreach v in class pba in_person{
	forvalues i=0(1)100{
		sum  misclassified_`v'_`i'
			replace  misclassified_`v'_`i'=r(mean)
	} 	
}
	 
keep misclassified_class_* misclassified_pba_*  misclassified_in_person_*
duplicates drop

gen id=1

reshape long misclassified_pba_ misclassified_class_ misclassified_in_person_, i(id) j(threshold)  string
keep  threshold misclassified_class_ misclassified_pba_ misclassified_in_person_
	destring threshold, replace

* Labeling	
	label variable misclassified_pba_ "Share of students misclassified by PBA"
	label variable misclassified_class_ "Share of students misclassified by previous in-class assessment"
	label variable misclassified_in_person_ "Share of students misclassified by in-person recreation of PBA"
	

	
*=== Actually producting graph	
sort threshold	
	keep if threshold<51
line misclassified_pba_ misclassified_class_  threshold,  legend(order(1 "Share of students misclassified by phone-based assessment (PBA)" 2 "Share of students misclassified by previous in-class assessment") cols(1)) legend(size(small)) title("Numeracy: relative misclassification rate of students by different thresholds," "students from households reporting any COVID-19-related shock", size(medium)) xtitle("Misclassification threshold", size(medsmall)) ytitle("Share of students misclassified", size(medsmall)) lpattern (solid dash)

restore
}

