*=================================================
* Appendix Figure 1: How different are students reached from those not reached?	
*=================================================
* 
use "$clean_pba_english", clear


* Setting the list of covariates
local covs population female_literacy povertymean distance_to_celltower managerattendance teacherattendance pupilattendance enrollment share_female_school enrollment_target share_female_target mean_ptr std_mar21_math std_mar21_kiswahili std_mar21_english	

qui{
local cols = 4 // control size, T/C diff (plus p-val), T1/T2 diff (plus p-val))
local rows:   list sizeof covs
local spacerows=1
	local rows=`rows'*(1+`spacerows')+1 // one line between each input plus an observations line
	
* Initializing the matrix
matrix results = J(`rows', `cols', .)
																 
local row = 1
local col = 1
*=== Saving column names (years)
global colnames "Reached p_val Reached p_val"
	local colnames="$colnames"
	matrix colnames results = `colnames'

matlist 	results
	
*=== Saving row names (variables)
global rownames ""
	local obs "Observations"
	local fill_in_blank=0
	local iterations=`spacerows'-1
		
global blank ""
forvalues i=0/`iterations'{	
	global blank "${blank} `fill_in_blank'"
}
di "$blank" // just checking

	foreach t of local covs {
		global rownames "${rownames} `t' ${blank}"
		}
		global rownames "${rownames} `obs'"
				local rownames="$rownames"
	matrix rownames results = `rownames'
				macro drop rownames obs fill_in_blank blank // clean up
matlist results


*=== Adding observations at the bottom of the table
	sum population 
			local obs_total: di %4.2f r(N)	
		matrix results[`rows', 1] 	= `obs_total'	

*=== Actual balance test
* First column
foreach v in  `covs' {

* SStandardizing
sum `v'
	replace `v'=(`v'-r(mean))/r(sd)
	
* First model
		reg `v' reached, cluster(academycode)
					local b: di %4.2f _b[reached]
					local se: di %4.2f _se[reached]
					local p_val: di  %4.2f (2 * ttail(e(df_r), abs(_b[reached]/_se[reached])))
					local obs e(N)
	
			matrix results[`row', `col'] 	= `b'
			matrix results[`row'+1, `col'] 	= `se'
			matrix results[`row', `col'+1] 	= `p_val'
			matrix results[`rows', `col'] 	= `obs'

		local col=`col'+2

* Second model			
		reg `v' reached i.assigned_assessor , cluster(academycode)
					local b: di %4.2f _b[reached]
					local se: di %4.2f _se[reached]
					local p_val: di  %4.2f (2 * ttail(e(df_r), abs(_b[reached]/_se[reached])))
					local obs e(N)
	
			matrix results[`row', `col'] 	= `b'
			matrix results[`row'+1, `col'] 	= `se'
			matrix results[`row', `col'+1] 	= `p_val'
			matrix results[`rows', `col'] 	= `obs'
					
			local col=1
			local row=`row'+2
}
}

matlist results
