*=================================================
* Figure 3: relative misclassification of pupils by assessment
*=================================================
	
	
*===============================================================================
* Numeracy
use "$clean_pba_num_percentile", clear


*  Reshaping data so it is in the correct shape for plotting curves

foreach v in class pba in_person{
	forvalues i=0(1)100{
		sum  misclassified_`v'_`i'
			replace  misclassified_`v'_`i'=r(mean)
	} 	
}
	 
keep misclassified_class_* misclassified_pba_*  misclassified_in_person_*
duplicates drop

gen id=1

reshape long misclassified_pba_ misclassified_class_ misclassified_in_person_, i(id) j(threshold)  string
keep  threshold misclassified_class_ misclassified_pba_ misclassified_in_person_
	destring threshold, replace

* Labeling	
	label variable misclassified_pba_ "Share of students misclassified by PBA"
	label variable misclassified_class_ "Share of students misclassified by previous in-class assessment"
	label variable misclassified_in_person_ "Share of students misclassified by in-person recreation of PBA"
	

	
*=== Actually producting graph	
sort threshold	
	keep if threshold<51
line misclassified_pba_ misclassified_class_  threshold,  legend(order(1 "Share of students misclassified by phone-based assessment (PBA)" 2 "Share of students misclassified by previous in-class assessment") cols(1)) legend(size(small)) title("Numeracy: relative misclassification rate of students by different thresholds", size(medium)) xtitle("Misclassification threshold", size(medsmall)) ytitle("Share of students misclassified", size(medsmall)) lpattern (solid dash)




*===============================================================================
* Literacy

use "$clean_pba_lit_percentile", clear
	keep if total_score_english_pba!=.

*  Reshaping data so it is in the correct shape for plotting curves

foreach v in class pba{
	forvalues i=0(1)100{
		sum  misclassified_`v'_`i'
			replace  misclassified_`v'_`i'=r(mean)
	} 	
}
	
keep misclassified_class_* misclassified_pba_*  
	drop misclassified_pba_*_fluency misclassified_class_*_fluency
duplicates drop

gen id=1

reshape long misclassified_pba_ misclassified_class_, i(id) j(threshold)  string
keep  threshold misclassified_class_ misclassified_pba_
	destring threshold, replace

* Labeling	
	label variable misclassified_pba_ "Share of students misclassified by PBA"
	label variable misclassified_class_ "Share of students misclassified by previous in-class assessment"
	
	
*=== Actually producting graph	
sort threshold	
	keep if threshold<51
line misclassified_pba_ misclassified_class_  threshold,  legend(order(1 "Share of students misclassified by phone-based assessment (PBA)" 2 "Share of students misclassified by previous in-class assessment") cols(1)) legend(size(small)) title("Literacy: Relative misclassification rate of students by different thresholds", size(medium)) xtitle("Misclassification threshold", size(medsmall)) ytitle("Share of students misclassified", size(medsmall)) lpattern (solid dash)



*===============================================================================
* Fluency


use "$clean_pba_lit_percentile", clear
	keep if total_score_english_pba!=.

*  Reshaping data so it is in the correct shape for plotting curves

foreach v in class pba{
	forvalues i=0(1)100{
		sum  misclassified_`v'_`i'_fluency
			replace  misclassified_`v'_`i'_fluency=r(mean)
	} 	
}

	
keep misclassified_class_*_fluency misclassified_pba_*_fluency  
duplicates drop

forvalues i=0/100{
	rename misclassified_pba_`i'_fluency misclassified_pba_`i'
	rename misclassified_class_`i'_fluency misclassified_class_`i'

}

gen id=1

reshape long misclassified_pba_ misclassified_class_, i(id) j(threshold)  string
keep  threshold misclassified_class_ misclassified_pba_
	destring threshold, replace

* Labeling	
	label variable misclassified_pba_ "Share of students misclassified by PBA"
	label variable misclassified_class_ "Share of students misclassified by previous in-class assessment"
	
	
*=== Actually producting graph	
sort threshold	
	keep if threshold<51
line misclassified_pba_ misclassified_class_  threshold,  legend(order(1 "Share of students misclassified by phone-based assessment (PBA)" 2 "Share of students misclassified by previous in-class assessment") cols(1)) legend(size(small)) title("Fluency: Relative misclassification rate of students by different thresholds", size(medium)) xtitle("Misclassification threshold", size(medsmall)) ytitle("Share of students misclassified", size(medsmall)) lpattern (solid dash)

