*=================================================
* Table 2b: descriptive statistics for the literacy assessment, broken down by section and grade (including Cronbach's alpha)
*=================================================

cls
use "$clean_pba_literacy", clear

local cols = 1 // full sample (since there is only one grade)
local rows=  4*4 // four sub-skills across four statistics

* Initializing the matrix
matrix results = J(`rows', `cols', .)
																 
local row = 1
local col = 1
*=== Saving column names 
global colnames "Full_sample_G3"
	local colnames="$colnames"
	matrix colnames results = `colnames'

*=== Saving row names
global rownames "Oral_comp SD alpha Obs Spelling SD alpha Obs Vocabulary SD alpha Obs Fluency SD alpha Obs"
	local rownames="$rownames"
	matrix rownames results = `rownames'	

*============================================
* Oral comprehension score

egen oral_comp=mean(oral_comprehension_1-oral_comprehension_4)
sum oral_comp if reached==1
				local mean: di %12.2f r(mean)	
				local sd: di %12.2f r(sd)	
				local n: di %12.2f r(N)	

		matrix results[`row', 1] 	= `mean'
		matrix results[`row'+1, 1] 	= `sd'
		matrix results[`row'+3, 1] 	= `n'

alpha oral_comprehension_1-oral_comprehension_4 if reached==1, item
				local alpha: di %12.2f r(alpha)	
				matrix results[`row'+2, 1] 	= `alpha'

	local row=`row'+4
	local col=1
	
	
*============================================
* Spelling score

egen spell=mean(spelling_1-spelling_4)
sum spell if reached==1
				local mean: di %12.2f r(mean)	
				local sd: di %12.2f r(sd)	
				local n: di %12.2f r(N)	

		matrix results[`row', 1] 	= `mean'
		matrix results[`row'+1, 1] 	= `sd'
		matrix results[`row'+3, 1] 	= `n'

alpha spelling_1-spelling_4 if reached==1, item
				local alpha: di %12.2f r(alpha)	
				matrix results[`row'+2, 1] 	= `alpha'

	local row=`row'+4
	local col=1

	
*============================================
* Vocabulary score

sum vocabulary if reached==1
				local mean: di %12.2f r(mean)	
				local sd: di %12.2f r(sd)	
				local n: di %12.2f r(N)	

		matrix results[`row', 1] 	= `mean'
		matrix results[`row'+1, 1] 	= `sd'
		matrix results[`row'+3, 1] 	= `n'

	local row=`row'+4
	local col=1

	

*============================================
* Fluency score

sum fluency_avg if reached==1
				local mean: di %12.2f r(mean)	
				local sd: di %12.2f r(sd)	
				local n: di %12.2f r(N)	

		matrix results[`row', 1] 	= `mean'
		matrix results[`row'+1, 1] 	= `sd'
		matrix results[`row'+3, 1] 	= `n'

alpha fluency_1-fluency_2 if reached==1, item
				local alpha: di %12.2f r(alpha)	
				matrix results[`row'+2, 1] 	= `alpha'


*=== Checking results				
matlist results	
	